sdv.lite.tabular.TabularPreset.list\_available\_presets
=======================================================

.. currentmodule:: sdv.lite.tabular

.. automethod:: TabularPreset.list_available_presets